@@ -1,6 +1,6 @@
 import json
 import os
-from datetime import datetime, timezone
+from datetime import datetime, timedelta, timezone
 
 import pytest
 
@@ -205,6 +205,16 @@ allow if fact($var, true);
 allow if fact($var, true) trusting ed25519/acdd6d5b53bfee478bf689f8e012fe7988bf755e3d7c5152947abc149bc20189;
 """
 
+
+def test_authorizer_limits():
+    auth = Authorizer("")
+    limits = auth.limits()
+    limits.max_time = timedelta(microseconds=2000)
+    auth.set_limits(limits)
+    limits = auth.limits()
+    assert limits.max_time.microseconds == 2000
+
+
 def test_key_selection():
     private_key = PrivateKey.from_hex("473b5189232f3f597b5c2f3f9b0d5e28b1ee4e7cce67ec6b7fbf5984157a6b97")
     root = KeyPair.from_private_key(private_key)
@@ -431,4 +441,4 @@ def test_keypair_from_private_key_pem():
     private_key_pem = "-----BEGIN PRIVATE KEY-----\nMC4CAQAwBQYDK2VwBCIEIASZaU0NoF3KxABSZj5x1QwVOUZfiSbf6SAzz3qq1T1l\n-----END PRIVATE KEY-----"
     private_key_hex = "0499694d0da05dcac40052663e71d50c1539465f8926dfe92033cf7aaad53d65"
     kp = KeyPair.from_private_key_pem(pem=private_key_pem)
-    assert kp.private_key.to_hex() == private_key_hex
\ No newline at end of file
+    assert kp.private_key.to_hex() == private_key_hex
